# Wiking

Wiking is a Python web application development framework.

Wiking comes together with Wiking CMS -- an extensible content management
system built on top of this framework.


## License

Wiking is Free Software, distributed under the terms of the **GNU General Public
License v2 (GPLv2)**.  See the `COPYING` file for details.


## Installation

Wiking is a pure Python library running on Python 3.5 or later and
may be installed simply by `pip install wiking`.

## Usage

Documentation is included in the package.  To generate the HTML version, run
`make doc` from the package root directory.
